from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.TColGeom import *
from OCC.Core.TColStd import *
from OCC.Core.Convert import *
from OCC.Core.GeomAbs import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TColgp import *


class geomconvert:
	@overload
	@staticmethod
	def C0BSplineToArrayOfC1BSplineCurve(BS: Geom_BSplineCurve, tabBS: TColGeom_HArray1OfBSplineCurve, tolerance: float) -> None: ...
	@overload
	@staticmethod
	def C0BSplineToArrayOfC1BSplineCurve(BS: Geom_BSplineCurve, tabBS: TColGeom_HArray1OfBSplineCurve, AngularTolerance: float, tolerance: float) -> None: ...
	@staticmethod
	def C0BSplineToC1BSplineCurve(BS: Geom_BSplineCurve, tolerance: float, AngularTolerance: Optional[float] = 1.0e-7) -> None: ...
	@overload
	@staticmethod
	def ConcatC1(ArrayOfCurves: TColGeom_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfIndices: TColStd_HArray1OfInteger, ArrayOfConcatenated: TColGeom_HArray1OfBSplineCurve, ClosedTolerance: float) -> bool: ...
	@overload
	@staticmethod
	def ConcatC1(ArrayOfCurves: TColGeom_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfIndices: TColStd_HArray1OfInteger, ArrayOfConcatenated: TColGeom_HArray1OfBSplineCurve, ClosedTolerance: float, AngularTolerance: float) -> bool: ...
	@staticmethod
	def ConcatG1(ArrayOfCurves: TColGeom_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfConcatenated: TColGeom_HArray1OfBSplineCurve, ClosedTolerance: float) -> bool: ...
	@staticmethod
	def CurveToBSplineCurve(C: Geom_Curve, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> Geom_BSplineCurve: ...
	@overload
	@staticmethod
	def SplitBSplineCurve(C: Geom_BSplineCurve, FromK1: int, ToK2: int, SameOrientation: Optional[bool] = True) -> Geom_BSplineCurve: ...
	@overload
	@staticmethod
	def SplitBSplineCurve(C: Geom_BSplineCurve, FromU1: float, ToU2: float, ParametricTolerance: float, SameOrientation: Optional[bool] = True) -> Geom_BSplineCurve: ...
	@overload
	@staticmethod
	def SplitBSplineSurface(S: Geom_BSplineSurface, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, SameUOrientation: Optional[bool] = True, SameVOrientation: Optional[bool] = True) -> Geom_BSplineSurface: ...
	@overload
	@staticmethod
	def SplitBSplineSurface(S: Geom_BSplineSurface, FromK1: int, ToK2: int, USplit: bool, SameOrientation: Optional[bool] = True) -> Geom_BSplineSurface: ...
	@overload
	@staticmethod
	def SplitBSplineSurface(S: Geom_BSplineSurface, FromU1: float, ToU2: float, FromV1: float, ToV2: float, ParametricTolerance: float, SameUOrientation: Optional[bool] = True, SameVOrientation: Optional[bool] = True) -> Geom_BSplineSurface: ...
	@overload
	@staticmethod
	def SplitBSplineSurface(S: Geom_BSplineSurface, FromParam1: float, ToParam2: float, USplit: bool, ParametricTolerance: float, SameOrientation: Optional[bool] = True) -> Geom_BSplineSurface: ...
	@staticmethod
	def SurfaceToBSplineSurface(S: Geom_Surface) -> Geom_BSplineSurface: ...

class GeomConvert_ApproxCurve:
	@overload
	def __init__(self, Curve: Geom_Curve, Tol3d: float, Order: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> None: ...
	@overload
	def __init__(self, Curve: Adaptor3d_HCurve, Tol3d: float, Order: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> None: ...
	def Curve(self) -> Geom_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError(self) -> float: ...

class GeomConvert_ApproxSurface:
	@overload
	def __init__(self, Surf: Geom_Surface, Tol3d: float, UContinuity: GeomAbs_Shape, VContinuity: GeomAbs_Shape, MaxDegU: int, MaxDegV: int, MaxSegments: int, PrecisCode: int) -> None: ...
	@overload
	def __init__(self, Surf: Adaptor3d_HSurface, Tol3d: float, UContinuity: GeomAbs_Shape, VContinuity: GeomAbs_Shape, MaxDegU: int, MaxDegV: int, MaxSegments: int, PrecisCode: int) -> None: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError(self) -> float: ...
	def Surface(self) -> Geom_BSplineSurface: ...

class GeomConvert_BSplineCurveKnotSplitting:
	def __init__(self, BasisCurve: Geom_BSplineCurve, ContinuityRange: int) -> None: ...
	def NbSplits(self) -> int: ...
	def SplitValue(self, Index: int) -> int: ...
	def Splitting(self, SplitValues: TColStd_Array1OfInteger) -> None: ...

class GeomConvert_BSplineCurveToBezierCurve:
	@overload
	def __init__(self, BasisCurve: Geom_BSplineCurve) -> None: ...
	@overload
	def __init__(self, BasisCurve: Geom_BSplineCurve, U1: float, U2: float, ParametricTolerance: float) -> None: ...
	def Arc(self, Index: int) -> Geom_BezierCurve: ...
	def Arcs(self, Curves: TColGeom_Array1OfBezierCurve) -> None: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def NbArcs(self) -> int: ...

class GeomConvert_BSplineSurfaceKnotSplitting:
	def __init__(self, BasisSurface: Geom_BSplineSurface, UContinuityRange: int, VContinuityRange: int) -> None: ...
	def NbUSplits(self) -> int: ...
	def NbVSplits(self) -> int: ...
	def Splitting(self, USplit: TColStd_Array1OfInteger, VSplit: TColStd_Array1OfInteger) -> None: ...
	def USplitValue(self, UIndex: int) -> int: ...
	def VSplitValue(self, VIndex: int) -> int: ...

class GeomConvert_BSplineSurfaceToBezierSurface:
	@overload
	def __init__(self, BasisSurface: Geom_BSplineSurface) -> None: ...
	@overload
	def __init__(self, BasisSurface: Geom_BSplineSurface, U1: float, U2: float, V1: float, V2: float, ParametricTolerance: float) -> None: ...
	def NbUPatches(self) -> int: ...
	def NbVPatches(self) -> int: ...
	def Patch(self, UIndex: int, VIndex: int) -> Geom_BezierSurface: ...
	def Patches(self, Surfaces: TColGeom_Array2OfBezierSurface) -> None: ...
	def UKnots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def VKnots(self, TKnots: TColStd_Array1OfReal) -> None: ...

class GeomConvert_CompBezierSurfacesToBSplineSurface:
	@overload
	def __init__(self, Beziers: TColGeom_Array2OfBezierSurface) -> None: ...
	@overload
	def __init__(self, Beziers: TColGeom_Array2OfBezierSurface, Tolerance: float, RemoveKnots: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Beziers: TColGeom_Array2OfBezierSurface, UKnots: TColStd_Array1OfReal, VKnots: TColStd_Array1OfReal, UContinuity: Optional[GeomAbs_Shape] = GeomAbs_C0, VContinuity: Optional[GeomAbs_Shape] = GeomAbs_C0, Tolerance: Optional[float] = 1.0e-4) -> None: ...
	def IsDone(self) -> bool: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def Poles(self) -> TColgp_HArray2OfPnt: ...
	def UDegree(self) -> int: ...
	def UKnots(self) -> TColStd_HArray1OfReal: ...
	def UMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def VDegree(self) -> int: ...
	def VKnots(self) -> TColStd_HArray1OfReal: ...
	def VMultiplicities(self) -> TColStd_HArray1OfInteger: ...

class GeomConvert_CompCurveToBSplineCurve:
	@overload
	def __init__(self, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	@overload
	def __init__(self, BasisCurve: Geom_BoundedCurve, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	def Add(self, NewCurve: Geom_BoundedCurve, Tolerance: float, After: Optional[bool] = False, WithRatio: Optional[bool] = True, MinM: Optional[int] = 0) -> bool: ...
	def BSplineCurve(self) -> Geom_BSplineCurve: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomconvert_C0BSplineToArrayOfC1BSplineCurve = geomconvert.C0BSplineToArrayOfC1BSplineCurve
geomconvert_C0BSplineToArrayOfC1BSplineCurve = geomconvert.C0BSplineToArrayOfC1BSplineCurve
geomconvert_C0BSplineToC1BSplineCurve = geomconvert.C0BSplineToC1BSplineCurve
geomconvert_ConcatC1 = geomconvert.ConcatC1
geomconvert_ConcatC1 = geomconvert.ConcatC1
geomconvert_ConcatG1 = geomconvert.ConcatG1
geomconvert_CurveToBSplineCurve = geomconvert.CurveToBSplineCurve
geomconvert_SplitBSplineCurve = geomconvert.SplitBSplineCurve
geomconvert_SplitBSplineCurve = geomconvert.SplitBSplineCurve
geomconvert_SplitBSplineSurface = geomconvert.SplitBSplineSurface
geomconvert_SplitBSplineSurface = geomconvert.SplitBSplineSurface
geomconvert_SplitBSplineSurface = geomconvert.SplitBSplineSurface
geomconvert_SplitBSplineSurface = geomconvert.SplitBSplineSurface
geomconvert_SurfaceToBSplineSurface = geomconvert.SurfaceToBSplineSurface



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.TDF import *
from OCC.Core.TCollection import *

TDataStd_PtrTreeNode = NewType('TDataStd_PtrTreeNode', TDataStd_TreeNode)

class TDataStd_LabelArray1:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TDF_Label: ...
    def __setitem__(self, index: int, value: TDF_Label) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TDF_Label]: ...
    def next(self) -> TDF_Label: ...
    __next__ = next
    def Init(self, theValue: TDF_Label) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TDF_Label: ...
    def Last(self) -> TDF_Label: ...
    def Value(self, theIndex: int) -> TDF_Label: ...
    def SetValue(self, theIndex: int, theValue: TDF_Label) -> None: ...

class TDataStd_ListOfByte:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> str: ...
    def Last(self) -> str: ...
    def Append(self, theItem: str) -> str: ...
    def Prepend(self, theItem: str) -> str: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> str: ...
    def SetValue(self, theIndex: int, theValue: str) -> None: ...

class TDataStd_ListOfExtendedString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TCollection_ExtendedString: ...
    def Last(self) -> TCollection_ExtendedString: ...
    def Append(self, theItem: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
    def Prepend(self, theItem: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TCollection_ExtendedString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_ExtendedString) -> None: ...

class TDataStd_RealEnum(IntEnum):
	TDataStd_SCALAR: int = ...
	TDataStd_LENGTH: int = ...
	TDataStd_ANGULAR: int = ...
TDataStd_SCALAR = TDataStd_RealEnum.TDataStd_SCALAR
TDataStd_LENGTH = TDataStd_RealEnum.TDataStd_LENGTH
TDataStd_ANGULAR = TDataStd_RealEnum.TDataStd_ANGULAR

class tdatastd:
	@staticmethod
	def IDList(anIDList: TDF_IDList) -> None: ...

class TDataStd_AsciiString(TDF_Attribute):
	def __init__(self) -> None: ...
	def Get(self) -> TCollection_AsciiString: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def IsEmpty(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, string: TCollection_AsciiString) -> TDataStd_AsciiString: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, guid: Standard_GUID, string: TCollection_AsciiString) -> TDataStd_AsciiString: ...
	@overload
	def Set(self, S: TCollection_AsciiString) -> None: ...
	@overload
	def SetID(self, guid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_BooleanArray(TDF_Attribute):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def InternalArray(self) -> TColStd_HArray1OfByte: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int) -> TDataStd_BooleanArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int) -> TDataStd_BooleanArray: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetInternalArray(self, values: TColStd_HArray1OfByte) -> None: ...
	def SetValue(self, index: int, value: bool) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> bool: ...

class TDataStd_BooleanList(TDF_Attribute):
	def __init__(self) -> None: ...
	def Append(self, value: bool) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def First(self) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def InsertAfter(self, index: int, after_value: bool) -> bool: ...
	def InsertBefore(self, index: int, before_value: bool) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> bool: ...
	def List(self) -> TDataStd_ListOfByte: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, value: bool) -> None: ...
	def Remove(self, index: int) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_BooleanList: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID) -> TDataStd_BooleanList: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_ByteArray(TDF_Attribute):
	def __init__(self) -> None: ...
	def ChangeArray(self, newArray: TColStd_HArray1OfByte, isCheckItems: Optional[bool] = True) -> None: ...
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	def GetDelta(self) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def InternalArray(self) -> TColStd_HArray1OfByte: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_ByteArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_ByteArray: ...
	def SetDelta(self, isDelta: bool) -> None: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetValue(self, index: int, value: str) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> str: ...

class TDataStd_ChildNodeIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aTreeNode: TDataStd_TreeNode, allLevels: Optional[bool] = False) -> None: ...
	def Initialize(self, aTreeNode: TDataStd_TreeNode, allLevels: Optional[bool] = False) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def NextBrother(self) -> None: ...
	def Value(self) -> TDataStd_TreeNode: ...

class TDataStd_Current(TDF_Attribute):
	def __init__(self) -> None: ...
	@staticmethod
	def Get(acces: TDF_Label) -> TDF_Label: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetLabel(self) -> TDF_Label: ...
	@staticmethod
	def Has(acces: TDF_Label) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(L: TDF_Label) -> None: ...
	def SetLabel(self, current: TDF_Label) -> None: ...

class TDataStd_DeltaOnModificationOfByteArray(TDF_DeltaOnModification):
	def __init__(self, Arr: TDataStd_ByteArray) -> None: ...
	def Apply(self) -> None: ...

class TDataStd_DeltaOnModificationOfExtStringArray(TDF_DeltaOnModification):
	def __init__(self, Arr: TDataStd_ExtStringArray) -> None: ...
	def Apply(self) -> None: ...

class TDataStd_DeltaOnModificationOfIntArray(TDF_DeltaOnModification):
	def __init__(self, Arr: TDataStd_IntegerArray) -> None: ...
	def Apply(self) -> None: ...

class TDataStd_DeltaOnModificationOfIntPackedMap(TDF_DeltaOnModification):
	def __init__(self, Arr: TDataStd_IntPackedMap) -> None: ...
	def Apply(self) -> None: ...

class TDataStd_DeltaOnModificationOfRealArray(TDF_DeltaOnModification):
	def __init__(self, Arr: TDataStd_RealArray) -> None: ...
	def Apply(self) -> None: ...

class TDataStd_Expression(TDF_Attribute):
	def __init__(self) -> None: ...
	def GetExpression(self) -> TCollection_ExtendedString: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetVariables(self) -> TDF_AttributeList: ...
	def ID(self) -> Standard_GUID: ...
	def Name(self) -> TCollection_ExtendedString: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_Expression: ...
	def SetExpression(self, E: TCollection_ExtendedString) -> None: ...

class TDataStd_ExtStringArray(TDF_Attribute):
	def __init__(self) -> None: ...
	def Array(self) -> TColStd_HArray1OfExtendedString: ...
	def ChangeArray(self, newArray: TColStd_HArray1OfExtendedString, isCheckItems: Optional[bool] = True) -> None: ...
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	def GetDelta(self) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_ExtStringArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_ExtStringArray: ...
	def SetDelta(self, isDelta: bool) -> None: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetValue(self, Index: int, Value: TCollection_ExtendedString) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> TCollection_ExtendedString: ...

class TDataStd_ExtStringList(TDF_Attribute):
	def __init__(self) -> None: ...
	def Append(self, value: TCollection_ExtendedString) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def First(self) -> TCollection_ExtendedString: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	def InsertAfter(self, value: TCollection_ExtendedString, after_value: TCollection_ExtendedString) -> bool: ...
	@overload
	def InsertAfter(self, index: int, after_value: TCollection_ExtendedString) -> bool: ...
	@overload
	def InsertBefore(self, value: TCollection_ExtendedString, before_value: TCollection_ExtendedString) -> bool: ...
	@overload
	def InsertBefore(self, index: int, before_value: TCollection_ExtendedString) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> TCollection_ExtendedString: ...
	def List(self) -> TDataStd_ListOfExtendedString: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, value: TCollection_ExtendedString) -> None: ...
	@overload
	def Remove(self, value: TCollection_ExtendedString) -> bool: ...
	@overload
	def Remove(self, index: int) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_ExtStringList: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID) -> TDataStd_ExtStringList: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_HDataMapOfStringByte(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TDataStd_DataMapOfStringByte) -> None: ...
	def ChangeMap(self) -> TDataStd_DataMapOfStringByte: ...
	def Map(self) -> TDataStd_DataMapOfStringByte: ...

class TDataStd_HDataMapOfStringHArray1OfInteger(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TDataStd_DataMapOfStringHArray1OfInteger) -> None: ...
	def ChangeMap(self) -> TDataStd_DataMapOfStringHArray1OfInteger: ...
	def Map(self) -> TDataStd_DataMapOfStringHArray1OfInteger: ...

class TDataStd_HDataMapOfStringHArray1OfReal(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TDataStd_DataMapOfStringHArray1OfReal) -> None: ...
	def ChangeMap(self) -> TDataStd_DataMapOfStringHArray1OfReal: ...
	def Map(self) -> TDataStd_DataMapOfStringHArray1OfReal: ...

class TDataStd_HDataMapOfStringInteger(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TColStd_DataMapOfStringInteger) -> None: ...
	def ChangeMap(self) -> TColStd_DataMapOfStringInteger: ...
	def Map(self) -> TColStd_DataMapOfStringInteger: ...

class TDataStd_HDataMapOfStringReal(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TDataStd_DataMapOfStringReal) -> None: ...
	def ChangeMap(self) -> TDataStd_DataMapOfStringReal: ...
	def Map(self) -> TDataStd_DataMapOfStringReal: ...

class TDataStd_HDataMapOfStringString(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TDataStd_DataMapOfStringString) -> None: ...
	def ChangeMap(self) -> TDataStd_DataMapOfStringString: ...
	def Map(self) -> TDataStd_DataMapOfStringString: ...

class TDataStd_IntPackedMap(TDF_Attribute):
	def __init__(self) -> None: ...
	def Add(self, theKey: int) -> bool: ...
	@overload
	def ChangeMap(self, theMap: TColStd_HPackedMapOfInteger) -> bool: ...
	@overload
	def ChangeMap(self, theMap: TColStd_PackedMapOfInteger) -> bool: ...
	def Clear(self) -> bool: ...
	def Contains(self, theKey: int) -> bool: ...
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	def Extent(self) -> int: ...
	def GetDelta(self) -> bool: ...
	def GetHMap(self) -> TColStd_HPackedMapOfInteger: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetMap(self) -> TColStd_PackedMapOfInteger: ...
	def ID(self) -> Standard_GUID: ...
	def IsEmpty(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Remove(self, theKey: int) -> bool: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label, isDelta: Optional[bool] = False) -> TDataStd_IntPackedMap: ...
	def SetDelta(self, isDelta: bool) -> None: ...

class TDataStd_Integer(TDF_Attribute):
	def __init__(self) -> None: ...
	def Get(self) -> int: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def IsCaptured(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, value: int) -> TDataStd_Integer: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, guid: Standard_GUID, value: int) -> TDataStd_Integer: ...
	@overload
	def Set(self, V: int) -> None: ...
	@overload
	def SetID(self, guid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_IntegerArray(TDF_Attribute):
	def __init__(self) -> None: ...
	def Array(self) -> TColStd_HArray1OfInteger: ...
	def ChangeArray(self, newArray: TColStd_HArray1OfInteger, isCheckItems: Optional[bool] = True) -> None: ...
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	def GetDelta(self) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_IntegerArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_IntegerArray: ...
	def SetDelta(self, isDelta: bool) -> None: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetValue(self, Index: int, Value: int) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> int: ...

class TDataStd_IntegerList(TDF_Attribute):
	def __init__(self) -> None: ...
	def Append(self, value: int) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def First(self) -> int: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def InsertAfter(self, value: int, after_value: int) -> bool: ...
	def InsertAfterByIndex(self, index: int, after_value: int) -> bool: ...
	def InsertBefore(self, value: int, before_value: int) -> bool: ...
	def InsertBeforeByIndex(self, index: int, before_value: int) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> int: ...
	def List(self) -> TColStd_ListOfInteger: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, value: int) -> None: ...
	def Remove(self, value: int) -> bool: ...
	def RemoveByIndex(self, index: int) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_IntegerList: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID) -> TDataStd_IntegerList: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_NamedData(TDF_Attribute):
	def __init__(self) -> None: ...
	def ChangeArraysOfIntegers(self, theArraysOfIntegers: TDataStd_DataMapOfStringHArray1OfInteger) -> None: ...
	def ChangeArraysOfReals(self, theArraysOfReals: TDataStd_DataMapOfStringHArray1OfReal) -> None: ...
	def ChangeBytes(self, theBytes: TDataStd_DataMapOfStringByte) -> None: ...
	def ChangeIntegers(self, theIntegers: TColStd_DataMapOfStringInteger) -> None: ...
	def ChangeReals(self, theReals: TDataStd_DataMapOfStringReal) -> None: ...
	def ChangeStrings(self, theStrings: TDataStd_DataMapOfStringString) -> None: ...
	def Clear(self) -> None: ...
	def GetArrayOfIntegers(self, theName: TCollection_ExtendedString) -> TColStd_HArray1OfInteger: ...
	def GetArrayOfReals(self, theName: TCollection_ExtendedString) -> TColStd_HArray1OfReal: ...
	def GetArraysOfIntegersContainer(self) -> TDataStd_DataMapOfStringHArray1OfInteger: ...
	def GetArraysOfRealsContainer(self) -> TDataStd_DataMapOfStringHArray1OfReal: ...
	def GetByte(self, theName: TCollection_ExtendedString) -> str: ...
	def GetBytesContainer(self) -> TDataStd_DataMapOfStringByte: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetInteger(self, theName: TCollection_ExtendedString) -> int: ...
	def GetIntegersContainer(self) -> TColStd_DataMapOfStringInteger: ...
	def GetReal(self, theName: TCollection_ExtendedString) -> float: ...
	def GetRealsContainer(self) -> TDataStd_DataMapOfStringReal: ...
	def GetString(self, theName: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
	def GetStringsContainer(self) -> TDataStd_DataMapOfStringString: ...
	def HasArrayOfIntegers(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasArrayOfReals(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasArraysOfIntegers(self) -> bool: ...
	def HasArraysOfReals(self) -> bool: ...
	def HasByte(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasBytes(self) -> bool: ...
	def HasDeferredData(self) -> bool: ...
	def HasInteger(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasIntegers(self) -> bool: ...
	def HasReal(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasReals(self) -> bool: ...
	def HasString(self, theName: TCollection_ExtendedString) -> bool: ...
	def HasStrings(self) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def LoadDeferredData(self, theToKeepDeferred: Optional[bool] = false) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_NamedData: ...
	def SetArrayOfIntegers(self, theName: TCollection_ExtendedString, theArrayOfIntegers: TColStd_HArray1OfInteger) -> None: ...
	def SetArrayOfReals(self, theName: TCollection_ExtendedString, theArrayOfReals: TColStd_HArray1OfReal) -> None: ...
	def SetByte(self, theName: TCollection_ExtendedString, theByte: str) -> None: ...
	def SetInteger(self, theName: TCollection_ExtendedString, theInteger: int) -> None: ...
	def SetReal(self, theName: TCollection_ExtendedString, theReal: float) -> None: ...
	def SetString(self, theName: TCollection_ExtendedString, theString: TCollection_ExtendedString) -> None: ...
	def UnloadDeferredData(self) -> bool: ...
	def clear(self) -> None: ...
	def setArrayOfIntegers(self, theName: TCollection_ExtendedString, theArrayOfIntegers: TColStd_HArray1OfInteger) -> None: ...
	def setArrayOfReals(self, theName: TCollection_ExtendedString, theArrayOfReals: TColStd_HArray1OfReal) -> None: ...
	def setByte(self, theName: TCollection_ExtendedString, theByte: str) -> None: ...
	def setInteger(self, theName: TCollection_ExtendedString, theInteger: int) -> None: ...
	def setReal(self, theName: TCollection_ExtendedString, theReal: float) -> None: ...
	def setString(self, theName: TCollection_ExtendedString, theString: TCollection_ExtendedString) -> None: ...

class TDataStd_Real(TDF_Attribute):
	def __init__(self) -> None: ...
	def Get(self) -> float: ...
	def GetDimension(self) -> TDataStd_RealEnum: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def IsCaptured(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, value: float) -> TDataStd_Real: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, guid: Standard_GUID, value: float) -> TDataStd_Real: ...
	@overload
	def Set(self, V: float) -> None: ...
	def SetDimension(self, DIM: TDataStd_RealEnum) -> None: ...
	@overload
	def SetID(self, guid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_RealArray(TDF_Attribute):
	def __init__(self) -> None: ...
	def Array(self) -> TColStd_HArray1OfReal: ...
	def ChangeArray(self, newArray: TColStd_HArray1OfReal, isCheckItems: Optional[bool] = True) -> None: ...
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	def GetDelta(self) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_RealArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int, isDelta: Optional[bool] = False) -> TDataStd_RealArray: ...
	def SetDelta(self, isDelta: bool) -> None: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetValue(self, Index: int, Value: float) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> float: ...

class TDataStd_RealList(TDF_Attribute):
	def __init__(self) -> None: ...
	def Append(self, value: float) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def First(self) -> float: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def InsertAfter(self, value: float, after_value: float) -> bool: ...
	def InsertAfterByIndex(self, index: int, after_value: float) -> bool: ...
	def InsertBefore(self, value: float, before_value: float) -> bool: ...
	def InsertBeforeByIndex(self, index: int, before_value: float) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> float: ...
	def List(self) -> TColStd_ListOfReal: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, value: float) -> None: ...
	def Remove(self, value: float) -> bool: ...
	def RemoveByIndex(self, index: int) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_RealList: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID) -> TDataStd_RealList: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_ReferenceArray(TDF_Attribute):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Init(self, lower: int, upper: int) -> None: ...
	def InternalArray(self) -> TDataStd_HLabelArray1: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, lower: int, upper: int) -> TDataStd_ReferenceArray: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID, lower: int, upper: int) -> TDataStd_ReferenceArray: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...
	def SetInternalArray(self, values: TDataStd_HLabelArray1, isCheckItems: Optional[bool] = True) -> None: ...
	def SetValue(self, index: int, value: TDF_Label) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> TDF_Label: ...

class TDataStd_ReferenceList(TDF_Attribute):
	def __init__(self) -> None: ...
	def Append(self, value: TDF_Label) -> None: ...
	def Clear(self) -> None: ...
	def Extent(self) -> int: ...
	def First(self) -> TDF_Label: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	def InsertAfter(self, value: TDF_Label, after_value: TDF_Label) -> bool: ...
	@overload
	def InsertAfter(self, index: int, after_value: TDF_Label) -> bool: ...
	@overload
	def InsertBefore(self, value: TDF_Label, before_value: TDF_Label) -> bool: ...
	@overload
	def InsertBefore(self, index: int, before_value: TDF_Label) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Last(self) -> TDF_Label: ...
	def List(self) -> TDF_LabelList: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, value: TDF_Label) -> None: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	@overload
	def Remove(self, value: TDF_Label) -> bool: ...
	@overload
	def Remove(self, index: int) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_ReferenceList: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, theGuid: Standard_GUID) -> TDataStd_ReferenceList: ...
	@overload
	def SetID(self, theGuid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_TreeNode(TDF_Attribute):
	def __init__(self) -> None: ...
	def AfterAddition(self) -> None: ...
	def AfterResume(self) -> None: ...
	def AfterUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def Append(self, Child: TDataStd_TreeNode) -> bool: ...
	def BeforeForget(self) -> None: ...
	def BeforeUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def Depth(self) -> int: ...
	def Father(self) -> TDataStd_TreeNode: ...
	@staticmethod
	def Find(L: TDF_Label, T: TDataStd_TreeNode) -> bool: ...
	def FindLast(self) -> TDataStd_TreeNode: ...
	def First(self) -> TDataStd_TreeNode: ...
	@staticmethod
	def GetDefaultTreeID() -> Standard_GUID: ...
	def HasFather(self) -> bool: ...
	def HasFirst(self) -> bool: ...
	def HasLast(self) -> bool: ...
	def HasNext(self) -> bool: ...
	def HasPrevious(self) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def InsertAfter(self, Node: TDataStd_TreeNode) -> bool: ...
	def InsertBefore(self, Node: TDataStd_TreeNode) -> bool: ...
	def IsAscendant(self, of: TDataStd_TreeNode) -> bool: ...
	def IsChild(self, of: TDataStd_TreeNode) -> bool: ...
	def IsDescendant(self, of: TDataStd_TreeNode) -> bool: ...
	def IsFather(self, of: TDataStd_TreeNode) -> bool: ...
	def IsRoot(self) -> bool: ...
	def Last(self) -> TDataStd_TreeNode: ...
	def NbChildren(self, allLevels: Optional[bool] = False) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Next(self) -> TDataStd_TreeNode: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Prepend(self, Child: TDataStd_TreeNode) -> bool: ...
	def Previous(self) -> TDataStd_TreeNode: ...
	def References(self, aDataSet: TDF_DataSet) -> None: ...
	def Remove(self) -> bool: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	def Root(self) -> TDataStd_TreeNode: ...
	@overload
	@staticmethod
	def Set(L: TDF_Label) -> TDataStd_TreeNode: ...
	@overload
	@staticmethod
	def Set(L: TDF_Label, ExplicitTreeID: Standard_GUID) -> TDataStd_TreeNode: ...
	def SetFather(self, F: TDataStd_TreeNode) -> None: ...
	def SetFirst(self, F: TDataStd_TreeNode) -> None: ...
	def SetLast(self, F: TDataStd_TreeNode) -> None: ...
	def SetNext(self, F: TDataStd_TreeNode) -> None: ...
	def SetPrevious(self, F: TDataStd_TreeNode) -> None: ...
	def SetTreeID(self, explicitID: Standard_GUID) -> None: ...

class TDataStd_UAttribute(TDF_Attribute):
	def __init__(self) -> None: ...
	def ID(self) -> Standard_GUID: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label, LocalID: Standard_GUID) -> TDataStd_UAttribute: ...
	def SetID(self, LocalID: Standard_GUID) -> None: ...

class TDataStd_Variable(TDF_Attribute):
	def __init__(self) -> None: ...
	def Assign(self) -> TDataStd_Expression: ...
	def Constant(self, status: bool) -> None: ...
	def Desassign(self) -> None: ...
	def Expression(self) -> TDataStd_Expression: ...
	def Get(self) -> float: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def IsAssigned(self) -> bool: ...
	def IsCaptured(self) -> bool: ...
	def IsConstant(self) -> bool: ...
	def IsValued(self) -> bool: ...
	@overload
	def Name(self, string: TCollection_ExtendedString) -> None: ...
	@overload
	def Name(self) -> TCollection_ExtendedString: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Real(self) -> TDataStd_Real: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_Variable: ...
	@overload
	def Set(self, value: float) -> None: ...
	@overload
	def Set(self, value: float, dimension: TDataStd_RealEnum) -> None: ...
	@overload
	def Unit(self, unit: TCollection_AsciiString) -> None: ...
	@overload
	def Unit(self) -> TCollection_AsciiString: ...

class TDataStd_Comment(TDataStd_GenericExtString):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_Comment: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, string: TCollection_ExtendedString) -> TDataStd_Comment: ...
	@overload
	def Set(self, S: TCollection_ExtendedString) -> None: ...
	@overload
	def SetID(self, guid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_Directory(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def AddDirectory(dir: TDataStd_Directory) -> TDataStd_Directory: ...
	@staticmethod
	def Find(current: TDF_Label, D: TDataStd_Directory) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def MakeObjectLabel(dir: TDataStd_Directory) -> TDF_Label: ...
	@staticmethod
	def New(label: TDF_Label) -> TDataStd_Directory: ...

class TDataStd_Name(TDataStd_GenericExtString):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, string: TCollection_ExtendedString) -> TDataStd_Name: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, guid: Standard_GUID, string: TCollection_ExtendedString) -> TDataStd_Name: ...
	@overload
	def Set(self, S: TCollection_ExtendedString) -> None: ...
	@overload
	def SetID(self, guid: Standard_GUID) -> None: ...
	@overload
	def SetID(self) -> None: ...

class TDataStd_NoteBook(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@overload
	def Append(self, value: float, isExported: Optional[bool] = False) -> TDataStd_Real: ...
	@overload
	def Append(self, value: int, isExported: Optional[bool] = False) -> TDataStd_Integer: ...
	@staticmethod
	def Find(current: TDF_Label, N: TDataStd_NoteBook) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def New(label: TDF_Label) -> TDataStd_NoteBook: ...

class TDataStd_Relation(TDataStd_Expression):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetRelation(self) -> TCollection_ExtendedString: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_Relation: ...
	def SetRelation(self, E: TCollection_ExtendedString) -> None: ...

class TDataStd_Tick(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataStd_Tick: ...

#classnotwrapped
class TDataStd_GenericEmpty: ...

#classnotwrapped
class TDataStd_GenericExtString: ...

# harray1 classes

class TDataStd_HLabelArray1(TDataStd_LabelArray1, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TDataStd_LabelArray1: ...

# harray2 classes
# hsequence classes

tdatastd_IDList = tdatastd.IDList
tdatastd_Print = tdatastd.Print
TDataStd_AsciiString_GetID = TDataStd_AsciiString.GetID
TDataStd_AsciiString_Set = TDataStd_AsciiString.Set
TDataStd_AsciiString_Set = TDataStd_AsciiString.Set
TDataStd_BooleanArray_GetID = TDataStd_BooleanArray.GetID
TDataStd_BooleanArray_Set = TDataStd_BooleanArray.Set
TDataStd_BooleanArray_Set = TDataStd_BooleanArray.Set
TDataStd_BooleanList_GetID = TDataStd_BooleanList.GetID
TDataStd_BooleanList_Set = TDataStd_BooleanList.Set
TDataStd_BooleanList_Set = TDataStd_BooleanList.Set
TDataStd_ByteArray_GetID = TDataStd_ByteArray.GetID
TDataStd_ByteArray_Set = TDataStd_ByteArray.Set
TDataStd_ByteArray_Set = TDataStd_ByteArray.Set
TDataStd_Current_Get = TDataStd_Current.Get
TDataStd_Current_GetID = TDataStd_Current.GetID
TDataStd_Current_Has = TDataStd_Current.Has
TDataStd_Current_Set = TDataStd_Current.Set
TDataStd_Expression_GetID = TDataStd_Expression.GetID
TDataStd_Expression_Set = TDataStd_Expression.Set
TDataStd_ExtStringArray_GetID = TDataStd_ExtStringArray.GetID
TDataStd_ExtStringArray_Set = TDataStd_ExtStringArray.Set
TDataStd_ExtStringArray_Set = TDataStd_ExtStringArray.Set
TDataStd_ExtStringList_GetID = TDataStd_ExtStringList.GetID
TDataStd_ExtStringList_Set = TDataStd_ExtStringList.Set
TDataStd_ExtStringList_Set = TDataStd_ExtStringList.Set
TDataStd_IntPackedMap_GetID = TDataStd_IntPackedMap.GetID
TDataStd_IntPackedMap_Set = TDataStd_IntPackedMap.Set
TDataStd_Integer_GetID = TDataStd_Integer.GetID
TDataStd_Integer_Set = TDataStd_Integer.Set
TDataStd_Integer_Set = TDataStd_Integer.Set
TDataStd_IntegerArray_GetID = TDataStd_IntegerArray.GetID
TDataStd_IntegerArray_Set = TDataStd_IntegerArray.Set
TDataStd_IntegerArray_Set = TDataStd_IntegerArray.Set
TDataStd_IntegerList_GetID = TDataStd_IntegerList.GetID
TDataStd_IntegerList_Set = TDataStd_IntegerList.Set
TDataStd_IntegerList_Set = TDataStd_IntegerList.Set
TDataStd_NamedData_GetID = TDataStd_NamedData.GetID
TDataStd_NamedData_Set = TDataStd_NamedData.Set
TDataStd_Real_GetID = TDataStd_Real.GetID
TDataStd_Real_Set = TDataStd_Real.Set
TDataStd_Real_Set = TDataStd_Real.Set
TDataStd_RealArray_GetID = TDataStd_RealArray.GetID
TDataStd_RealArray_Set = TDataStd_RealArray.Set
TDataStd_RealArray_Set = TDataStd_RealArray.Set
TDataStd_RealList_GetID = TDataStd_RealList.GetID
TDataStd_RealList_Set = TDataStd_RealList.Set
TDataStd_RealList_Set = TDataStd_RealList.Set
TDataStd_ReferenceArray_GetID = TDataStd_ReferenceArray.GetID
TDataStd_ReferenceArray_Set = TDataStd_ReferenceArray.Set
TDataStd_ReferenceArray_Set = TDataStd_ReferenceArray.Set
TDataStd_ReferenceList_GetID = TDataStd_ReferenceList.GetID
TDataStd_ReferenceList_Set = TDataStd_ReferenceList.Set
TDataStd_ReferenceList_Set = TDataStd_ReferenceList.Set
TDataStd_TreeNode_Find = TDataStd_TreeNode.Find
TDataStd_TreeNode_GetDefaultTreeID = TDataStd_TreeNode.GetDefaultTreeID
TDataStd_TreeNode_Set = TDataStd_TreeNode.Set
TDataStd_TreeNode_Set = TDataStd_TreeNode.Set
TDataStd_UAttribute_Set = TDataStd_UAttribute.Set
TDataStd_Variable_GetID = TDataStd_Variable.GetID
TDataStd_Variable_Set = TDataStd_Variable.Set
TDataStd_Comment_GetID = TDataStd_Comment.GetID
TDataStd_Comment_Set = TDataStd_Comment.Set
TDataStd_Comment_Set = TDataStd_Comment.Set
TDataStd_Directory_AddDirectory = TDataStd_Directory.AddDirectory
TDataStd_Directory_Find = TDataStd_Directory.Find
TDataStd_Directory_GetID = TDataStd_Directory.GetID
TDataStd_Directory_MakeObjectLabel = TDataStd_Directory.MakeObjectLabel
TDataStd_Directory_New = TDataStd_Directory.New
TDataStd_Name_GetID = TDataStd_Name.GetID
TDataStd_Name_Set = TDataStd_Name.Set
TDataStd_Name_Set = TDataStd_Name.Set
TDataStd_NoteBook_Find = TDataStd_NoteBook.Find
TDataStd_NoteBook_GetID = TDataStd_NoteBook.GetID
TDataStd_NoteBook_New = TDataStd_NoteBook.New
TDataStd_Relation_GetID = TDataStd_Relation.GetID
TDataStd_Relation_Set = TDataStd_Relation.Set
TDataStd_Tick_GetID = TDataStd_Tick.GetID
TDataStd_Tick_Set = TDataStd_Tick.Set



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepTopAdaptor module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_breptopadaptor.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepTopAdaptor
else:
    import _BRepTopAdaptor

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepTopAdaptor.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepTopAdaptor.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepTopAdaptor.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepTopAdaptor.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepTopAdaptor.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepTopAdaptor.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepTopAdaptor.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepTopAdaptor.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepTopAdaptor.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepTopAdaptor.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepTopAdaptor.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepTopAdaptor.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepTopAdaptor.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepTopAdaptor.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepTopAdaptor.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepTopAdaptor.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepTopAdaptor.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepTopAdaptor:
_BRepTopAdaptor.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepTopAdaptor.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BRepTopAdaptor_HVertex_Create() -> "opencascade::handle< BRepTopAdaptor_HVertex >":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_HVertex_Create()

def Handle_BRepTopAdaptor_HVertex_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTopAdaptor_HVertex >":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_HVertex_DownCast(t)

def Handle_BRepTopAdaptor_HVertex_IsNull(t: "opencascade::handle< BRepTopAdaptor_HVertex > const &") -> "bool":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_HVertex_IsNull(t)

def Handle_BRepTopAdaptor_TopolTool_Create() -> "opencascade::handle< BRepTopAdaptor_TopolTool >":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_TopolTool_Create()

def Handle_BRepTopAdaptor_TopolTool_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTopAdaptor_TopolTool >":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_TopolTool_DownCast(t)

def Handle_BRepTopAdaptor_TopolTool_IsNull(t: "opencascade::handle< BRepTopAdaptor_TopolTool > const &") -> "bool":
    return _BRepTopAdaptor.Handle_BRepTopAdaptor_TopolTool_IsNull(t)
class BRepTopAdaptor_MapOfShapeTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher >::iterator":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher >::iterator":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_cend(self)

    def __init__(self, *args):
        _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_swiginit(self, _BRepTopAdaptor.new_BRepTopAdaptor_MapOfShapeTool(*args))

    def Exchange(self, theOther: "BRepTopAdaptor_MapOfShapeTool") -> "void":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Exchange(self, theOther)

    def Assign(self, theOther: "BRepTopAdaptor_MapOfShapeTool") -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher > &":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Assign(self, theOther)

    def Set(self, theOther: "BRepTopAdaptor_MapOfShapeTool") -> "NCollection_DataMap< TopoDS_Shape,BRepTopAdaptor_Tool,TopTools_ShapeMapHasher > &":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "BRepTopAdaptor_Tool") -> "Standard_Boolean":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "BRepTopAdaptor_Tool") -> "BRepTopAdaptor_Tool *":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "BRepTopAdaptor_Tool const *":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "BRepTopAdaptor_Tool *":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "BRepTopAdaptor_Tool &":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_ChangeFind(self, theKey)

    def __call__(self, *args) -> "BRepTopAdaptor_Tool &":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Clear(self, *args)
    __swig_destroy__ = _BRepTopAdaptor.delete_BRepTopAdaptor_MapOfShapeTool

    def Size(self) -> "Standard_Integer":
        return _BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_Size(self)

# Register BRepTopAdaptor_MapOfShapeTool in _BRepTopAdaptor:
_BRepTopAdaptor.BRepTopAdaptor_MapOfShapeTool_swigregister(BRepTopAdaptor_MapOfShapeTool)

class BRepTopAdaptor_FClass2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        Tol: float

        Returns
        -------
        None

        """
        _BRepTopAdaptor.BRepTopAdaptor_FClass2d_swiginit(self, _BRepTopAdaptor.new_BRepTopAdaptor_FClass2d(*args))

    def Copy(self, *args) -> "BRepTopAdaptor_FClass2d const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Other: BRepTopAdaptor_FClass2d

        Returns
        -------
        BRepTopAdaptor_FClass2d

        """
        return _BRepTopAdaptor.BRepTopAdaptor_FClass2d_Copy(self, *args)

    def Destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_FClass2d_Destroy(self, *args)

    def Perform(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        Puv: gp_Pnt2d
        RecadreOnPeriodic: bool,optional
        	default value is Standard_True

        Returns
        -------
        TopAbs_State

        """
        return _BRepTopAdaptor.BRepTopAdaptor_FClass2d_Perform(self, *args)

    def PerformInfinitePoint(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_State

        """
        return _BRepTopAdaptor.BRepTopAdaptor_FClass2d_PerformInfinitePoint(self, *args)

    def TestOnRestriction(self, *args) -> "TopAbs_State":
        r"""
        Test a point with +- an offset (tol) and returns on if some points are out an some are in (caution: internal use . see the code for more details).

        Parameters
        ----------
        Puv: gp_Pnt2d
        Tol: float
        RecadreOnPeriodic: bool,optional
        	default value is Standard_True

        Returns
        -------
        TopAbs_State

        """
        return _BRepTopAdaptor.BRepTopAdaptor_FClass2d_TestOnRestriction(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTopAdaptor.delete_BRepTopAdaptor_FClass2d

# Register BRepTopAdaptor_FClass2d in _BRepTopAdaptor:
_BRepTopAdaptor.BRepTopAdaptor_FClass2d_swigregister(BRepTopAdaptor_FClass2d)

class BRepTopAdaptor_HVertex(OCC.Core.Adaptor3d.Adaptor3d_HVertex):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Vtx: TopoDS_Vertex
        Curve: BRepAdaptor_HCurve2d

        Returns
        -------
        None

        """
        _BRepTopAdaptor.BRepTopAdaptor_HVertex_swiginit(self, _BRepTopAdaptor.new_BRepTopAdaptor_HVertex(*args))

    def ChangeVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepTopAdaptor.BRepTopAdaptor_HVertex_ChangeVertex(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepTopAdaptor.BRepTopAdaptor_HVertex_Vertex(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTopAdaptor_HVertex_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTopAdaptor.delete_BRepTopAdaptor_HVertex

# Register BRepTopAdaptor_HVertex in _BRepTopAdaptor:
_BRepTopAdaptor.BRepTopAdaptor_HVertex_swigregister(BRepTopAdaptor_HVertex)

class BRepTopAdaptor_Tool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        Tol2d: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Surface: Adaptor3d_HSurface
        Tol2d: float

        Returns
        -------
        None

        """
        _BRepTopAdaptor.BRepTopAdaptor_Tool_swiginit(self, _BRepTopAdaptor.new_BRepTopAdaptor_Tool(*args))

    def Destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_Tool_Destroy(self, *args)

    def GetSurface(self, *args) -> "opencascade::handle< Adaptor3d_HSurface >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Adaptor3d_HSurface>

        """
        return _BRepTopAdaptor.BRepTopAdaptor_Tool_GetSurface(self, *args)

    def GetTopolTool(self, *args) -> "opencascade::handle< BRepTopAdaptor_TopolTool >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<BRepTopAdaptor_TopolTool>

        """
        return _BRepTopAdaptor.BRepTopAdaptor_Tool_GetTopolTool(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        Tol2d: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Surface: Adaptor3d_HSurface
        Tol2d: float

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_Tool_Init(self, *args)

    def SetTopolTool(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TT: BRepTopAdaptor_TopolTool

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_Tool_SetTopolTool(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTopAdaptor.delete_BRepTopAdaptor_Tool

# Register BRepTopAdaptor_Tool in _BRepTopAdaptor:
_BRepTopAdaptor.BRepTopAdaptor_Tool_swigregister(BRepTopAdaptor_Tool)

class BRepTopAdaptor_TopolTool(OCC.Core.Adaptor3d.Adaptor3d_TopolTool):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Surface: Adaptor3d_HSurface

        Returns
        -------
        None

        """
        _BRepTopAdaptor.BRepTopAdaptor_TopolTool_swiginit(self, _BRepTopAdaptor.new_BRepTopAdaptor_TopolTool(*args))

    def Destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_TopolTool_Destroy(self, *args)

    def Initialize(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: Adaptor3d_HSurface

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Curve: Adaptor2d_HCurve2d

        Returns
        -------
        None

        """
        return _BRepTopAdaptor.BRepTopAdaptor_TopolTool_Initialize(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        If the function returns the orientation of the arc. if the orientation is forward or reversed, the arc is a 'real' limit of the surface. if the orientation is internal or external, the arc is considered as an arc on the surface.

        Parameters
        ----------
        C: Adaptor2d_HCurve2d

        Returns
        -------
        TopAbs_Orientation
        If the function returns the orientation of the arc. if the orientation is forward or reversed, the arc is a 'real' limit of the surface. if the orientation is internal or external, the arc is considered as an arc on the surface.

        Parameters
        ----------
        C: Adaptor3d_HVertex

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepTopAdaptor.BRepTopAdaptor_TopolTool_Orientation(self, *args)

    def Tol3d(self, *args) -> "Standard_Real":
        r"""
        Returns 3d tolerance of the arc c.

        Parameters
        ----------
        C: Adaptor2d_HCurve2d

        Returns
        -------
        float
        Returns 3d tolerance of the vertex v.

        Parameters
        ----------
        V: Adaptor3d_HVertex

        Returns
        -------
        float

        """
        return _BRepTopAdaptor.BRepTopAdaptor_TopolTool_Tol3d(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTopAdaptor_TopolTool_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTopAdaptor.delete_BRepTopAdaptor_TopolTool

# Register BRepTopAdaptor_TopolTool in _BRepTopAdaptor:
_BRepTopAdaptor.BRepTopAdaptor_TopolTool_swigregister(BRepTopAdaptor_TopolTool)


BRepTopAdaptor_SeqOfPtr=OCC.Core.TColStd.TColStd_SequenceOfAddress






from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.Adaptor2d import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.AppParCurves import *
from OCC.Core.math import *
from OCC.Core.Geom import *
from OCC.Core.GeomAdaptor import *


class ProjLib_SequenceOfHSequenceOfPnt:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class projlib:
	@staticmethod
	def IsAnaSurf(theAS: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def MakePCurveOfType(PC: ProjLib_ProjectedCurve, aC: Geom2d_Curve) -> None: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, P: gp_Pnt) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, L: gp_Lin) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, C: gp_Circ) -> gp_Circ2d: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, E: gp_Elips) -> gp_Elips2d: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, P: gp_Parab) -> gp_Parab2d: ...
	@overload
	@staticmethod
	def Project(Pl: gp_Pln, H: gp_Hypr) -> gp_Hypr2d: ...
	@overload
	@staticmethod
	def Project(Cy: gp_Cylinder, P: gp_Pnt) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Project(Cy: gp_Cylinder, L: gp_Lin) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(Cy: gp_Cylinder, Ci: gp_Circ) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(Co: gp_Cone, P: gp_Pnt) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Project(Co: gp_Cone, L: gp_Lin) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(Co: gp_Cone, Ci: gp_Circ) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(Sp: gp_Sphere, P: gp_Pnt) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Project(Sp: gp_Sphere, Ci: gp_Circ) -> gp_Lin2d: ...
	@overload
	@staticmethod
	def Project(To: gp_Torus, P: gp_Pnt) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Project(To: gp_Torus, Ci: gp_Circ) -> gp_Lin2d: ...

class ProjLib_CompProjectedCurve(Adaptor2d_Curve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve, TolU: float, TolV: float) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve, TolU: float, TolV: float, MaxDist: float) -> None: ...
	def Bounds(self, Index: int) -> Tuple[float, float]: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def FirstParameter(self) -> float: ...
	def GetCurve(self) -> Adaptor3d_HCurve: ...
	def GetSequence(self) -> ProjLib_HSequenceOfHSequenceOfPnt: ...
	def GetSurface(self) -> Adaptor3d_HSurface: ...
	def GetTolerance(self) -> Tuple[float, float]: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Init(self) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsSinglePnt(self, Index: int, P: gp_Pnt2d) -> bool: ...
	def IsUIso(self, Index: int) -> Tuple[bool, float]: ...
	def IsVIso(self, Index: int) -> Tuple[bool, float]: ...
	def LastParameter(self) -> float: ...
	@overload
	def Load(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Load(self, C: Adaptor3d_HCurve) -> None: ...
	def MaxDistance(self, Index: int) -> float: ...
	def NbCurves(self) -> int: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Trim(self, FirstParam: float, LastParam: float, Tol: float) -> Adaptor2d_HCurve2d: ...
	def Value(self, U: float) -> gp_Pnt2d: ...

class ProjLib_ComputeApprox:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	def BSpline(self) -> Geom2d_BSplineCurve: ...
	def Bezier(self) -> Geom2d_BezierCurve: ...
	def Perform(self, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface) -> None: ...
	def SetBndPnt(self, theBndPnt: AppParCurves_Constraint) -> None: ...
	def SetDegree(self, theDegMin: int, theDegMax: int) -> None: ...
	def SetMaxSegments(self, theMaxSegments: int) -> None: ...
	def SetTolerance(self, theTolerance: float) -> None: ...
	def Tolerance(self) -> float: ...

class ProjLib_ComputeApproxOnPolarSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface, Tol: Optional[float] = 1.0e-4) -> None: ...
	@overload
	def __init__(self, InitCurve2d: Adaptor2d_HCurve2d, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	@overload
	def __init__(self, InitCurve2d: Adaptor2d_HCurve2d, InitCurve2dBis: Adaptor2d_HCurve2d, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	def BSpline(self) -> Geom2d_BSplineCurve: ...
	def BuildInitialCurve2d(self, Curve: Adaptor3d_HCurve, S: Adaptor3d_HSurface) -> Adaptor2d_HCurve2d: ...
	def Curve2d(self) -> Geom2d_Curve: ...
	def IsDone(self) -> bool: ...
	@overload
	def Perform(self, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Perform(self, InitCurve2d: Adaptor2d_HCurve2d, C: Adaptor3d_HCurve, S: Adaptor3d_HSurface) -> Geom2d_BSplineCurve: ...
	def ProjectUsingInitialCurve2d(self, Curve: Adaptor3d_HCurve, S: Adaptor3d_HSurface, InitCurve2d: Adaptor2d_HCurve2d) -> Geom2d_BSplineCurve: ...
	def SetBndPnt(self, theBndPnt: AppParCurves_Constraint) -> None: ...
	def SetDegree(self, theDegMin: int, theDegMax: int) -> None: ...
	def SetMaxDist(self, theMaxDist: float) -> None: ...
	def SetMaxSegments(self, theMaxSegments: int) -> None: ...
	def SetTolerance(self, theTolerance: float) -> None: ...
	def Tolerance(self) -> float: ...

class ProjLib_HCompProjectedCurve(Adaptor2d_HCurve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: ProjLib_CompProjectedCurve) -> None: ...
	def ChangeCurve2d(self) -> ProjLib_CompProjectedCurve: ...
	def Curve2d(self) -> Adaptor2d_Curve2d: ...
	def Set(self, C: ProjLib_CompProjectedCurve) -> None: ...

class ProjLib_HProjectedCurve(Adaptor2d_HCurve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: ProjLib_ProjectedCurve) -> None: ...
	def ChangeCurve2d(self) -> ProjLib_ProjectedCurve: ...
	def Curve2d(self) -> Adaptor2d_Curve2d: ...
	def Set(self, C: ProjLib_ProjectedCurve) -> None: ...

class ProjLib_PrjFunc(math_FunctionSetWithDerivatives):
	def __init__(self, C: Adaptor3d_CurvePtr, FixVal: float, S: Adaptor3d_SurfacePtr, Fix: int) -> None: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Solution(self) -> gp_Pnt2d: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class ProjLib_PrjResolve:
	def __init__(self, C: Adaptor3d_Curve, S: Adaptor3d_Surface, Fix: int) -> None: ...
	def IsDone(self) -> bool: ...
	def Perform(self, t: float, U: float, V: float, Tol: gp_Pnt2d, Inf: gp_Pnt2d, Sup: gp_Pnt2d, FTol: Optional[float] = -1, StrictInside: Optional[bool] = False) -> None: ...
	def Solution(self) -> gp_Pnt2d: ...

class ProjLib_ProjectOnPlane(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Pl: gp_Ax3) -> None: ...
	@overload
	def __init__(self, Pl: gp_Ax3, D: gp_Dir) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetCurve(self) -> Adaptor3d_HCurve: ...
	def GetDirection(self) -> gp_Dir: ...
	def GetPlane(self) -> gp_Ax3: ...
	def GetResult(self) -> GeomAdaptor_HCurve: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	def Load(self, C: Adaptor3d_HCurve, Tolerance: float, KeepParametrization: Optional[bool] = True) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class ProjLib_ProjectOnSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def IsDone(self) -> bool: ...

class ProjLib_ProjectedCurve(Adaptor2d_Curve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, C: Adaptor3d_HCurve, Tol: float) -> None: ...
	def BSpline(self) -> Geom2d_BSplineCurve: ...
	def Bezier(self) -> Geom2d_BezierCurve: ...
	def Circle(self) -> gp_Circ2d: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips2d: ...
	def FirstParameter(self) -> float: ...
	def GetCurve(self) -> Adaptor3d_HCurve: ...
	def GetSurface(self) -> Adaptor3d_HSurface: ...
	def GetTolerance(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr2d: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin2d: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab2d: ...
	def Perform(self, C: Adaptor3d_HCurve) -> None: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def SetBndPnt(self, theBndPnt: AppParCurves_Constraint) -> None: ...
	def SetDegree(self, theDegMin: int, theDegMax: int) -> None: ...
	def SetMaxDist(self, theMaxDist: float) -> None: ...
	def SetMaxSegments(self, theMaxSegments: int) -> None: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor2d_HCurve2d: ...
	def Value(self, U: float) -> gp_Pnt2d: ...

class ProjLib_Projector:
	def __init__(self) -> None: ...
	def BSpline(self) -> Geom2d_BSplineCurve: ...
	def Bezier(self) -> Geom2d_BezierCurve: ...
	def Circle(self) -> gp_Circ2d: ...
	def Done(self) -> None: ...
	def Ellipse(self) -> gp_Elips2d: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr2d: ...
	def IsDone(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def Line(self) -> gp_Lin2d: ...
	def Parabola(self) -> gp_Parab2d: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...
	def SetBSpline(self, C: Geom2d_BSplineCurve) -> None: ...
	def SetBezier(self, C: Geom2d_BezierCurve) -> None: ...
	def SetPeriodic(self) -> None: ...
	def SetType(self, Type: GeomAbs_CurveType) -> None: ...
	def UFrame(self, CFirst: float, CLast: float, UFirst: float, Period: float) -> None: ...
	def VFrame(self, CFirst: float, CLast: float, VFirst: float, Period: float) -> None: ...

class ProjLib_Cone(ProjLib_Projector):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Co: gp_Cone) -> None: ...
	@overload
	def __init__(self, Co: gp_Cone, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, Co: gp_Cone, C: gp_Circ) -> None: ...
	def Init(self, Co: gp_Cone) -> None: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...

class ProjLib_Cylinder(ProjLib_Projector):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, C: gp_Circ) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, E: gp_Elips) -> None: ...
	def Init(self, Cyl: gp_Cylinder) -> None: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...

class ProjLib_Plane(ProjLib_Projector):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln, C: gp_Circ) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln, E: gp_Elips) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln, P: gp_Parab) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln, H: gp_Hypr) -> None: ...
	def Init(self, Pl: gp_Pln) -> None: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...

class ProjLib_Sphere(ProjLib_Projector):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sp: gp_Sphere) -> None: ...
	@overload
	def __init__(self, Sp: gp_Sphere, C: gp_Circ) -> None: ...
	def Init(self, Sp: gp_Sphere) -> None: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...
	def SetInBounds(self, U: float) -> None: ...

class ProjLib_Torus(ProjLib_Projector):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, To: gp_Torus) -> None: ...
	@overload
	def __init__(self, To: gp_Torus, C: gp_Circ) -> None: ...
	def Init(self, To: gp_Torus) -> None: ...
	@overload
	def Project(self, L: gp_Lin) -> None: ...
	@overload
	def Project(self, C: gp_Circ) -> None: ...
	@overload
	def Project(self, E: gp_Elips) -> None: ...
	@overload
	def Project(self, P: gp_Parab) -> None: ...
	@overload
	def Project(self, H: gp_Hypr) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

class ProjLib_HSequenceOfHSequenceOfPnt(ProjLib_SequenceOfHSequenceOfPnt, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: ProjLib_SequenceOfHSequenceOfPnt) -> None: ...
    def Sequence(self) -> ProjLib_SequenceOfHSequenceOfPnt: ...
    def Append(self, theSequence: ProjLib_SequenceOfHSequenceOfPnt) -> None: ...


projlib_IsAnaSurf = projlib.IsAnaSurf
projlib_MakePCurveOfType = projlib.MakePCurveOfType
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project
projlib_Project = projlib.Project



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.XmlMDF import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.XmlObjMgt import *


class xmlmfunction:
	@staticmethod
	def AddDrivers(aDriverTable: XmlMDF_ADriverTable, theMessageDriver: Message_Messenger) -> None: ...

class XmlMFunction_FunctionDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMFunction_GraphNodeDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMFunction_ScopeDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlmfunction_AddDrivers = xmlmfunction.AddDrivers



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.GeomAdaptor import *
from OCC.Core.gp import *
from OCC.Core.IntCurveSurface import *
from OCC.Core.TopAbs import *


class BRepIntCurveSurface_Inter:
	def __init__(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Init(self, theShape: TopoDS_Shape, theCurve: GeomAdaptor_Curve, theTol: float) -> None: ...
	@overload
	def Init(self, theShape: TopoDS_Shape, theLine: gp_Lin, theTol: float) -> None: ...
	@overload
	def Init(self, theCurve: GeomAdaptor_Curve) -> None: ...
	def Load(self, theShape: TopoDS_Shape, theTol: float) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Pnt(self) -> gp_Pnt: ...
	def Point(self) -> IntCurveSurface_IntersectionPoint: ...
	def State(self) -> TopAbs_State: ...
	def Transition(self) -> IntCurveSurface_TransitionOnCurve: ...
	def U(self) -> float: ...
	def V(self) -> float: ...
	def W(self) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

